@@ -8,11 +8,13 @@
 
 #pragma once
 
+#include <folly/io/IOBuf.h>
 #include <list>
 #include <memory>
 #include <proxygen/httpclient/samples/curl/CurlClient.h>
 #include <proxygen/httpserver/samples/hq/H1QUpstreamSession.h>
 #include <proxygen/httpserver/samples/hq/HQCommandLine.h>
+#include <proxygen/lib/http/HTTPMessage.h>
 #include <proxygen/lib/http/session/HQUpstreamSession.h>
 #include <quic/common/events/HighResQuicTimer.h>
 
@@ -31,6 +33,12 @@ class HQClient : private quic::QuicSocket::ConnectionSetupCallback {
 
   int start();
 
+  void setOnBodyFunc(
+      const std::function<void(const proxygen::HTTPMessage& request,
+                               const folly::IOBuf* chainBuf)>& onBodyFunc) {
+    onBodyFunc_ = onBodyFunc;
+  }
+
  private:
   // Conn setup callback
   void onConnectionSetupError(quic::QuicError code) noexcept override;
@@ -99,6 +107,10 @@ class HQClient : private quic::QuicSocket::ConnectionSetupCallback {
 
   std::deque<std::chrono::milliseconds> requestGaps_;
 
+  folly::Optional<std::function<void(const proxygen::HTTPMessage& request,
+                                     const folly::IOBuf* chainBuf)>>
+      onBodyFunc_;
+
   bool failed_{false};
 
   bool replaySafe_{false};
