@@ -137,6 +137,7 @@ DEFINE_bool(use_l4s_ecn, false, "Whether to use L4S for ECN marking");
 DEFINE_bool(read_ecn,
             false,
             "Whether to read and echo ecn marking from ingress packets");
+DEFINE_uint32(dscp, 0, "DSCP value to use for outgoing packets");
 
 namespace quic::samples {
 
@@ -161,10 +162,10 @@ namespace {
  * Initiazliation and validation functions.
  *
  * The pattern is to collect flags into the HQToolParamsBuilderFromCmdline
- * object and then to validate it. Rationale of validating the options AFTER all
- * the options have been collected: some combinations of transport, http and
- * partial reliability options are invalid. It is simpler to collect the options
- * first and to validate the combinations later.
+ * object and then to validate it. Rationale of validating the options AFTER
+ * all the options have been collected: some combinations of transport, http
+ * and partial reliability options are invalid. It is simpler to collect the
+ * options first and to validate the combinations later.
  *
  */
 void initializeCommonSettings(HQToolParams& hqParams) {
@@ -247,8 +248,8 @@ void initializeTransportSettings(HQToolParams& hqUberParams) {
   hqParams.transportSettings.enableWriterBackpressure =
       FLAGS_writer_backpressure;
   if (hqUberParams.mode == HQMode::CLIENT) {
-    // There is no good reason to keep the socket around for a drain period for
-    // a commandline client
+    // There is no good reason to keep the socket around for a drain period
+    // for a commandline client
     hqParams.transportSettings.shouldDrain = false;
     hqParams.transportSettings.attemptEarlyData = FLAGS_early_data;
   }
@@ -277,7 +278,6 @@ void initializeTransportSettings(HQToolParams& hqUberParams) {
                                                 kDefaultQuicTransportKnobId,
                                                 FLAGS_transport_knobs});
   }
-  hqParams.transportSettings.shouldRecvBatch = true;
   hqParams.transportSettings.maxRecvBatchSize = 32;
   hqParams.transportSettings.shouldUseRecvmmsgForBatchRecv = true;
   hqParams.transportSettings.advertisedInitialMaxStreamsBidi = 100;
@@ -303,11 +303,9 @@ void initializeTransportSettings(HQToolParams& hqUberParams) {
     hqParams.transportSettings.ccaConfig.leaveHeadroomForCwndLimited = true;
   }
 
-  if (FLAGS_read_ecn) {
-    hqParams.transportSettings.readEcnOnIngress = FLAGS_read_ecn;
-    hqParams.transportSettings.shouldRecvBatch = false;
-  }
+  hqParams.transportSettings.readEcnOnIngress = FLAGS_read_ecn;
 
+  hqParams.transportSettings.dscpValue = FLAGS_dscp;
 } // initializeTransportSettings
 
 void initializeHttpServerSettings(HQToolServerParams& hqParams) {
@@ -441,6 +439,7 @@ HQToolParamsBuilderFromCmdline::HQToolParamsBuilderFromCmdline(
   gflags::FlagSaver saver;
 
   for (auto& kv : initial) {
+    LOG(INFO) << "Overriding HQToolParams " << kv.first << " to " << kv.second;
     gflags::SetCommandLineOptionWithMode(
         kv.first.c_str(),
         kv.second.c_str(),
