@@ -133,9 +133,9 @@ class HTTP1xCodec : public HTTPCodec {
   }
 
   /**
-   * @returns true if the codec supports the given NPN protocol.
+   * @returns true if the codec supports the given ALPN protocol.
    */
-  static bool supportsNextProtocol(const std::string& npn);
+  static bool supportsNextProtocol(folly::StringPiece alpn);
 
  private:
   /** Simple state model used to track the parsing of HTTP headers */
