@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Facebook, Inc. and its affiliates.
+ * Copyright (c) Meta Platforms, Inc. and affiliates.
  * All rights reserved.
  *
  * This source code is licensed under the BSD-style license found in the
@@ -27,11 +27,13 @@ class HTTPChecks : public PassThroughHTTPCodecFilter {
 
   // HTTPCodec methods
 
-  void generateHeader(folly::IOBufQueue& writeBuf,
-                      StreamID stream,
-                      const HTTPMessage& msg,
-                      bool eom,
-                      HTTPHeaderSize* sizeOut) override;
+  void generateHeader(
+      folly::IOBufQueue& writeBuf,
+      StreamID stream,
+      const HTTPMessage& msg,
+      bool eom,
+      HTTPHeaderSize* sizeOut,
+      const folly::Optional<HTTPHeaders>& extraHeaders = folly::none) override;
 };
 
 } // namespace proxygen
