@@ -8,6 +8,8 @@
 
 #pragma once
 
+#include <limits>
+
 #include <glog/logging.h>
 
 #include <proxygen/lib/http/codec/compress/HPACKHeader.h>
@@ -22,7 +24,7 @@ namespace proxygen {
 
 class QPACKHeaderTable : public HeaderTable {
  public:
-  enum { UNACKED = std::numeric_limits<uint32_t>::max() };
+  static constexpr uint32_t UNACKED = std::numeric_limits<uint32_t>::max();
 
   QPACKHeaderTable(uint32_t capacityVal, bool trackReferences);
 
@@ -159,16 +161,10 @@ class QPACKHeaderTable : public HeaderTable {
     return insertCount_ - absIndex + 1;
   }
 
-  /**
-   * Add a reference for the given index.  Entries with non-zero references
-   * cannot be evicted
-   */
-  void addRef(uint32_t absIndex);
-
-  /**
-   * Subtract a reference for the given index
-   */
-  void subRef(uint32_t absIndex);
+  void setMinInUseIndex(
+      uint32_t minInUseIndex = std::numeric_limits<uint32_t>::max()) {
+    minInUseIndex_ = minInUseIndex;
+  }
 
  private:
   /*
@@ -184,11 +180,6 @@ class QPACKHeaderTable : public HeaderTable {
    */
   void increaseTableLengthTo(uint32_t newLength) override;
 
-  void resizeTable(uint32_t newLength) override;
-
-  void updateResizedTable(uint32_t oldTail,
-                          uint32_t oldLength,
-                          uint32_t newLength) override;
   /**
    * Removes one header entry from the beginning of the header table.
    */
@@ -216,7 +207,8 @@ class QPACKHeaderTable : public HeaderTable {
   uint32_t minUsable_{1};
   uint32_t ackedInsertCount_{0};
   uint32_t minFree_{0};
-  std::unique_ptr<std::vector<uint16_t>> refCount_;
+  bool trackReferences_{false};
+  uint32_t minInUseIndex_{std::numeric_limits<uint32_t>::max()};
 };
 
 } // namespace proxygen
