@@ -7,6 +7,7 @@
  */
 
 #include <proxygen/lib/http/session/HQUpstreamSession.h>
+#include <quic/common/events/FollyQuicEventBase.h>
 #include <wangle/acceptor/ConnectionManager.h>
 
 namespace proxygen {
@@ -117,24 +118,26 @@ bool HQUpstreamSession::isDetachable(bool checkSocket) const {
   return getNumOutgoingStreams() == 0 && getNumIncomingStreams() == 0;
 }
 
-void HQUpstreamSession::attachThreadLocals(folly::EventBase* eventBase,
-                                           folly::SSLContextPtr,
-                                           const WheelTimerInstance& timeout,
-                                           HTTPSessionStats* stats,
-                                           FilterIteratorFn fn,
-                                           HeaderCodec::Stats* headerCodecStats,
-                                           HTTPSessionController* controller) {
+void HQUpstreamSession::attachThreadLocals(
+    folly::EventBase* eventBase,
+    std::shared_ptr<const folly::SSLContext>,
+    const WheelTimerInstance& timeout,
+    HTTPSessionStats* stats,
+    FilterIteratorFn fn,
+    HeaderCodec::Stats* headerCodecStats,
+    HTTPSessionController* controller) {
   // TODO: deal with control streams in h2q
   VLOG(4) << __func__ << " sess=" << *this;
   txnEgressQueue_.attachThreadLocals(timeout);
   setController(controller);
   setSessionStats(stats);
+  auto qEvbWrapper = std::make_shared<quic::FollyQuicEventBase>(eventBase);
   if (sock_) {
-    sock_->attachEventBase(eventBase);
+    sock_->attachEventBase(std::move(qEvbWrapper));
   }
   codec_.foreach (fn);
   setHeaderCodecStats(headerCodecStats);
-  sock_->getEventBase()->runInLoop(this);
+  getEventBase()->runInLoop(this);
   // The caller MUST re-add the connection to a new connection manager.
 }
 
@@ -162,13 +165,6 @@ void HQUpstreamSession::detachThreadLocals(bool) {
   }
 }
 
-void HQUpstreamSession::onNetworkSwitch(
-    std::unique_ptr<folly::AsyncUDPSocket> newSock) noexcept {
-  if (sock_) {
-    sock_->onNetworkSwitch(std::move(newSock));
-  }
-}
-
 bool HQUpstreamSession::tryBindIngressStreamToTxn(
     quic::StreamId streamId,
     hq::PushId pushId,
@@ -292,9 +288,9 @@ uint32_t HQUpstreamSession::numberOfIngressPushStreams() const {
   return ingressPushStreams_.size();
 }
 
-void HQUpstreamSession::onNewPushStream(quic::StreamId pushStreamId,
-                                        hq::PushId pushId,
-                                        size_t toConsume) {
+void HQUpstreamSession::dispatchPushStream(quic::StreamId pushStreamId,
+                                           hq::PushId pushId,
+                                           size_t toConsume) {
   VLOG(4) << __func__ << " streamID=" << pushStreamId << " pushId=" << pushId;
 
   // TODO: if/when we support client goaway, reject stream if
