@@ -32,6 +32,20 @@ class HTTPSessionStats : public TTLBAStats {
   virtual void recordPendingBufferedWriteBytes(int64_t) noexcept {
   }
   virtual void recordEgressContentLengthMismatches() noexcept = 0;
+  virtual void recordSessionPeriodicPingProbeTimeout() noexcept = 0;
+
+  virtual void recordControlMsgsInInterval(int64_t) noexcept {
+  }
+  virtual void recordControlMsgRateLimited() noexcept {
+  }
+  virtual void recordHeadersInInterval(int64_t) noexcept {
+  }
+  virtual void recordHeadersRateLimited() noexcept {
+  }
+  virtual void recordResetsInInterval(int64_t) noexcept {
+  }
+  virtual void recordResetsRateLimited() noexcept {
+  }
 };
 
 } // namespace proxygen
