@@ -681,6 +681,13 @@ class HTTPTransaction
       folly::assume_unreachable();
     }
 
+    virtual folly::Expected<folly::Unit, WebTransport::ErrorCode>
+    setWebTransportStreamPriority(HTTPCodec::StreamID /*id*/,
+                                  HTTPPriority /*pri*/) {
+      LOG(FATAL) << __func__ << " not supported";
+      folly::assume_unreachable();
+    }
+
     virtual folly::Expected<folly::Unit, WebTransport::ErrorCode>
     pauseWebTransportIngress(HTTPCodec::StreamID /*id*/) {
       LOG(FATAL) << __func__ << " not supported";
@@ -1285,7 +1292,19 @@ class HTTPTransaction
    * This function may also cause additional callbacks such as
    * detachTransaction() to the handler either immediately or after it returns.
    */
-  virtual void sendAbort();
+  void sendAbort();
+
+  /**
+   * Identical to above, but user may supply an error code.
+   *
+   * Note:
+   * Downstream sessions invoking ::sendAbort(NO_ERROR) after egressing eom will
+   * queue the RST_STREAM/STOP_SENDING NO_ERROR (if the protocol supports such
+   * sematics). This is different from the typical behaviour of *immediately*
+   * terminating both ingress and egress (and therefore dropping any buffered
+   * data) with other ErrorCodes.
+   */
+  virtual void sendAbort(ErrorCode statusCode);
 
   /**
    * Pause ingress processing.  Upon pause, the HTTPTransaction
@@ -1744,11 +1763,8 @@ class HTTPTransaction
    * to it.
    */
   void checkCreateDeferredIngress();
-
-  /**
-   * Implementation of sending an abort for this transaction.
-   */
-  void sendAbort(ErrorCode statusCode);
+  // Implementation of sending an abort for this transaction.
+  size_t sendAbortImpl(ErrorCode statusCode);
 
   // Internal implementations of the ingress-related callbacks
   // that work whether the ingress events are immediate or deferred.
@@ -1832,6 +1848,10 @@ class HTTPTransaction
 
   void rateLimitTimeoutExpired();
 
+  // If deferredNoError_ is set to true, it invokes ::sendAbort() w/ NO_ERROR
+  // and returns the number of bytes written to the transport
+  size_t maybeSendDeferredNoError();
+
   class RateLimitCallback : public folly::HHWheelTimer::Callback {
    public:
     explicit RateLimitCallback(HTTPTransaction& txn) : txn_(txn) {
@@ -2026,6 +2046,14 @@ class HTTPTransaction
   // Whether this HTTPTransaction delegates body sending to another entity.
   bool isDelegated_ : 1;
 
+  /**
+   * If set, the transaction will flush a RST_STREAM/NO_ERROR (h2) or
+   * STOP_SENDING/NO_ERROR (h3) after eom. This is only set if ::abort() is
+   * invoked with ErrorCode::NO_ERROR on a downstream transaction after eom has
+   * been queued.
+   */
+  bool deferredNoError_ : 1;
+
   /**
    * If this transaction represents a request (ie, it is backed by an
    * HTTPUpstreamSession) , this field indicates the last response status
@@ -2128,6 +2156,15 @@ class HTTPTransaction
       }
       return it->second.resetStream(error);
     }
+    folly::Expected<folly::Unit, WebTransport::ErrorCode> setPriority(
+        uint64_t id, uint8_t level, uint64_t order, bool incremental) override {
+      auto it = txn_.wtEgressStreams_.find(id);
+      if (it == txn_.wtEgressStreams_.end()) {
+        return folly::makeUnexpected(
+            WebTransport::ErrorCode::INVALID_STREAM_ID);
+      }
+      return it->second.setPriority(level, order, incremental);
+    }
     folly::Expected<folly::Unit, WebTransport::ErrorCode> sendDatagram(
         std::unique_ptr<folly::IOBuf> datagram) override {
       if (!txn_.sendDatagram(std::move(datagram))) {
@@ -2175,6 +2212,12 @@ class HTTPTransaction
       return txn_.resetWebTransportEgress(id_, errorCode);
     }
 
+    folly::Expected<folly::Unit, WebTransport::ErrorCode> setPriority(
+        uint8_t level, uint64_t order, bool incremental) override {
+      return txn_.transport_.setWebTransportStreamPriority(
+          getID(), {level, incremental, order});
+    }
+
     void onStopSending(uint32_t errorCode);
 
     void onEgressReady();
