@@ -377,17 +377,24 @@ class MockHTTPTransaction : public HTTPTransaction {
   MOCK_METHOD(bool, canSendHeaders, (), (const));
   MOCK_METHOD(void, sendHeaders, (const HTTPMessage& headers));
   MOCK_METHOD(void, sendHeadersWithEOM, (const HTTPMessage& headers));
+  MOCK_METHOD(void,
+              sendHeadersWithOptionalEOM,
+              (const HTTPMessage& headers, bool eom));
   MOCK_METHOD(void, sendBody, (std::shared_ptr<folly::IOBuf>));
 
   void sendBody(std::unique_ptr<folly::IOBuf> iob) noexcept override {
     sendBody(std::shared_ptr<folly::IOBuf>(iob.release()));
   }
 
+  void sendAbort() {
+    return HTTPTransaction::sendAbort();
+  }
+
   MOCK_METHOD(void, sendChunkHeader, (size_t));
   MOCK_METHOD(void, sendChunkTerminator, ());
   MOCK_METHOD(void, sendTrailers, (const HTTPHeaders& trailers));
   MOCK_METHOD(void, sendEOM, ());
-  MOCK_METHOD(void, sendAbort, ());
+  MOCK_METHOD(void, sendAbort, (ErrorCode errorCode));
   MOCK_METHOD(void, drop, ());
   MOCK_METHOD(void, pauseIngress, ());
   MOCK_METHOD(void, resumeIngress, ());
