@@ -1,12 +1,12 @@
 /*
- * Copyright (c) Facebook, Inc. and its affiliates.
+ * Copyright (c) Meta Platforms, Inc. and affiliates.
  * All rights reserved.
  *
  * This source code is licensed under the BSD-style license found in the
  * LICENSE file in the root directory of this source tree.
  */
 
-#include "proxygen/lib/pools/generators/ServerListGenerator.h"
+#include <proxygen/lib/pools/generators/ServerListGenerator.h>
 
 #include <folly/Conv.h>
 #include <folly/io/async/EventBase.h>
