@@ -8,7 +8,7 @@
 
 #include <proxygen/lib/transport/H3DatagramAsyncSocket.h>
 
-#include <fizz/protocol/CertUtils.h>
+#include <fizz/backend/openssl/certificate/CertUtils.h>
 #include <folly/FileUtil.h>
 #include <quic/common/udpsocket/FollyQuicAsyncUDPSocket.h>
 #include <quic/fizz/client/handshake/FizzClientQuicHandshakeContext.h>
@@ -133,23 +133,90 @@ void H3DatagramAsyncSocket::deliverDatagram(
   ReadCallback::OnDataAvailableParams params;
   CHECK(readCallback_);
   CHECK(datagram);
-  readCallback_->getReadBuffer(&buf, &len);
-  if (buf == nullptr || len == 0 || len < datagram->computeChainDataLength()) {
-    LOG(ERROR) << "Buffer too small to deliver "
-               << datagram->computeChainDataLength() << " bytes datagram";
-    return;
+  if (!readCallback_->shouldOnlyNotify()) {
+
+    readCallback_->getReadBuffer(&buf, &len);
+    if (buf == nullptr || len == 0 ||
+        len < datagram->computeChainDataLength()) {
+      LOG(ERROR) << "Buffer too small to deliver "
+                 << datagram->computeChainDataLength() << " bytes datagram";
+      return;
+    }
+    datagram->coalesce();
+    memcpy(buf, datagram->data(), datagram->length());
+    readCallback_->onDataAvailable((upstreamSession_
+                                        ? upstreamSession_->getPeerAddress()
+                                        : connectAddress_),
+                                   size_t(datagram->length()),
+                                   /*truncated*/ false,
+                                   params);
+  } else {
+    datagram->coalesce();
+    pendingDelivery_ = std::move(datagram);
+    readCallback_->onNotifyDataAvailable(*this);
   }
-  datagram->coalesce();
-  memcpy(buf, datagram->data(), datagram->length());
-  readCallback_->onDataAvailable(
-      (upstreamSession_ ? upstreamSession_->getPeerAddress() : connectAddress_),
-      size_t(datagram->length()),
-      /*truncated*/ false,
-      params);
+}
+
+ssize_t H3DatagramAsyncSocket::recvmsg(struct msghdr* msg, int /*flags*/) {
+  if (!pendingDelivery_) {
+    return 0;
+  }
+  // This isn't ideal because we are doing double copies, but it is a
+  // limitation of the interface for now.
+  memcpy(msg->msg_iov[0].iov_base,
+         pendingDelivery_->data(),
+         pendingDelivery_->length());
+  ssize_t ret = pendingDelivery_->length();
+  pendingDelivery_ = nullptr;
+  return ret;
+}
+
+int H3DatagramAsyncSocket::recvmmsg(struct mmsghdr* msgvec,
+                                    unsigned int vlen,
+                                    unsigned int flags,
+                                    struct timespec* /*timeout*/) {
+  CHECK_GT(vlen, 0);
+  auto bytesReceived = recvmsg(&msgvec->msg_hdr, flags);
+  if (bytesReceived < 0) {
+    return -1;
+  }
+  msgvec->msg_len = bytesReceived;
+  return 1;
 }
 
 void H3DatagramAsyncSocket::onBody(
-    std::unique_ptr<folly::IOBuf> /*chain*/) noexcept {
+    std::unique_ptr<folly::IOBuf> body) noexcept {
+  if (!options_.capsuleCallback_) {
+    return;
+  }
+  // TODO this only supports parsing capsules that come in one
+  // onBody call and isn't a proper streaming parser.
+  folly::io::Cursor cursor(body.get());
+  auto leftToParse = body->computeChainDataLength();
+  while (leftToParse > 0) {
+    auto typeRes = quic::decodeQuicInteger(cursor, leftToParse);
+    if (!typeRes) {
+      LOG(ERROR) << "Failed to decode capsule type.";
+      return;
+    }
+    auto [type, typeLen] = typeRes.value();
+    leftToParse -= typeLen;
+    auto capLengthRes = quic::decodeQuicInteger(cursor, leftToParse);
+    if (!capLengthRes) {
+      LOG(ERROR) << "Failed to decode capsule length: type=" << type;
+      return;
+    }
+    auto [capLength, capLengthLen] = capLengthRes.value();
+    leftToParse -= capLengthLen;
+    if (capLength > leftToParse) {
+      LOG(ERROR) << "Not enough data for capsule: type=" << type
+                 << " length=" << capLength;
+      return;
+    }
+    H3Capsule ret{type, capLength, nullptr};
+    cursor.cloneAtMost(ret.data, capLength);
+    options_.capsuleCallback_(std::move(ret));
+  }
 }
 
 void H3DatagramAsyncSocket::onTrailers(
@@ -242,7 +309,7 @@ H3DatagramAsyncSocket::createFizzClientContext() {
     folly::readFile(options_.certAndKey_->first.c_str(), certData);
     std::string keyData;
     folly::readFile(options_.certAndKey_->second.c_str(), keyData);
-    auto cert = fizz::CertUtils::makeSelfCert(certData, keyData);
+    auto cert = fizz::openssl::CertUtils::makeSelfCert(certData, keyData);
     ctx->setClientCertificate(std::move(cert));
   }
 
